<?php

// http://docs.whmcs.com/Editing_Client_Area_Menus
use WHMCS\View\Menu\Item as MenuItem;

// We use this hook to override the WHMCS default manage private nameservers page
// As well as email forwarding and dns modification pages as well
add_hook('ClientAreaPrimarySidebar', 1, function (MenuItem $primarySidebar) {

    // Get the domain being visited and grab the id of it
    // http://docs.whmcs.com/classes/classes/WHMCS.Domain.Domain.html
    $domain              = Menu::context('domain');
    $hasEmailForwarding  = $domain->hasEmailForwarding;
    $hasDNSManagement    = $domain->hasDnsManagement;
    $hasIdProtection     = $domain->hasIdProtection;
    $registrarModuleName = $domain->registrarModuleName;

    // Make sure the domain belongs to the Synergy Wholesale Domains module before we go forth
    // and hide the default pages
    if ($registrarModuleName == "synergywholesaledomains") {

        // If the Manage Private Nameservers page is defined, rid ourselves of it
        if (!is_null($primarySidebar->getChild('Domain Details Management')) && !is_null($primarySidebar->getChild('Domain Details Management')->getChild('Manage Private Nameservers'))) {
            $primarySidebar->getChild('Domain Details Management')->removeChild('Manage Private Nameservers');
        }

        // If we can find the user has dns management addon enabled, we hide WHMCS default page
        if ($hasDNSManagement) {
            if (!is_null($primarySidebar->getChild('Domain Details Management')) && !is_null($primarySidebar->getChild('Domain Details Management')->getChild('Manage DNS Host Records'))) {
                $primarySidebar->getChild('Domain Details Management')->removeChild('Manage DNS Host Records');
            }
        }

        // If we can find the user has email forwarding addon enabled, we hide the WHMCS default page
        if ($hasEmailForwarding) {
            if (!is_null($primarySidebar->getChild('Domain Details Management')) && !is_null($primarySidebar->getChild('Domain Details Management')->getChild('Manage Email Forwarding'))) {
                $primarySidebar->getChild('Domain Details Management')->removeChild('Manage Email Forwarding');
            }
        }
    }
});

// We use this hook to override the WHMCS default domain dns management page
// We want to go to our custom page, as long as the registrarModuleName is set and
// is pointing to our custom module
add_hook('ClientAreaPageDomainDNSManagement', 1, function ($vars) {

    // Map the domain id
    $domainid = $vars['domainid'];

    // If the registarModule under dnsrecords -> vars is set then assign it
    // Otherwise is null
    if (isset($vars['dnsrecords']['vars']['registrarModule'])) {
        $registrarModuleName = $vars['dnsrecords']['vars']['registrarModule'];
    } else {
        $registrarModuleName = null;
    }

    // If the registrarModuleName is not null and equals synergywholesaledomains
    if (!is_null($registrarModuleName) && $registrarModuleName == "synergywholesaledomains") {
        // Redirect to our custom page
        header("Location: clientarea.php?action=domaindetails&id=" . $domainid . "&modop=custom&a=manageDNSURLForwarding");
    }

});

// We use this hook to override the WHMCS default domain email forwarding page
// We want to go to our custom page, as long as the registrarModuleName is set and
// is pointing to our custom module
add_hook('ClientAreaPageDomainEmailForwarding', 1, function ($vars) {

    // Map the domain id
    $domainid = $vars['domainid'];

    // If the registarModule under dnsrecords -> vars is set then assign it
    // Otherwise is null
    if (isset($vars['emailforwarders']['vars']['registrarModule'])) {
        $registrarModuleName = $vars['emailforwarders']['vars']['registrarModule'];
    } else {
        $registrarModuleName = null;
    }

    // If the registrarModuleName is not null and equals synergywholesaledomains
    if (!is_null($registrarModuleName) && $registrarModuleName == "synergywholesaledomains") {
        // Redirect to our custom page
        header("Location: clientarea.php?action=domaindetails&id=" . $domainid . "&modop=custom&a=manageEmailForwarding");
    }

});
