// --------------------------------------------------
// Toastr related functionality starts here
// --------------------------------------------------
if (typeof toastr !== "undefined") {
    toastr.options.positionClass = "toast-top-full-width";
    toastr.options.extendedTimeOut = 0;
    //1000;
    toastr.options.timeOut = 1e4;
    toastr.options.fadeOut = 500;
    toastr.options.fadeIn = 500;
}

function Toast(type, css, msg) {
    toastr.options.positionClass = css;
    toastr[type](msg);
}

// --------------------------------------------------
// Any Email Record related functionality starts here
// --------------------------------------------------
// List email records
function listMailRecords(domainid) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageEmailForwarding&op=getRecords";
    var type = "POST";
    var timeout = 1e4;
    var formdata = "";
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url, formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        for (i = 0; i < data.length; i++) {
            populateEmailRow(data[i].recordID, data[i].prefix, data[i].forwardto);
        }
        Toast("success", "toast-top-right", "Successfully retreieved EMail Forwards");
    });
}

// Add an email record
function addEmailRecord(domainid, temprecordid, formdata) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof temprecordid === "undefined") {
        returnResp.error = "temprecordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageEmailForwarding&op=addRecord";
    var type = "POST";
    var timeout = 1e4;
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url, formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        $("#emailrow-" + temprecordid).attr("id", "emailrow-" + data.recordID);
        $("#emailform-" + temprecordid).attr("id", "emailform-" + data.recordID);
        $("#newemailrecordid-" + temprecordid).attr("id", "emailrecordid-" + data.recordID);
        $("#emailrecordid-" + data.recordID).val(data.recordID);
        Toast("success", "toast-top-right", "EMail forwarder successfully added");
    });
}

// Delete email record
function deleteEmailRecord(domainid, recordid, formdata) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof recordid === "undefined") {
        returnResp.error = "recordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageEmailForwarding&op=deleteRecord";
    var type = "POST";
    var timeout = 1e4;
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url, formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        // Remove the row
        $("#emailrow-" + recordid).remove();
        // Success message
        Toast("success", "toast-top-right", "EMail Forwarder successfully deleted");
    });
}

// Save email forwarder
function saveEmailRecord(domainid, recordid, formdata) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof recordid === "undefined") {
        returnResp.error = "recordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageEmailForwarding&op=";
    var type = "POST";
    var timeout = 1e4;
    // Execute the AJAX Call to delete record
    var promise = executeAJAXRequest(type, url + "deleteRecord", formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        // Execute the AJAX Call to add record
        var promise = executeAJAXRequest(type, url + "addRecord", formdata, timeout).fail(errorHandler);
        promise.done(function(data) {
            $("#emailrow-" + recordid).attr("id", "emailrow-" + data.recordID);
            $("#emailform-" + recordid).attr("id", "emailform-" + data.recordID);
            $("#newemailrecordid-" + recordid).attr("id", "emailrecordid-" + data.recordID);
            $("#emailrecordid-" + data.recordID).val(data.recordID);
            Toast("success", "toast-top-right", "Successfully updated Email Forwarder");
        });
    });
}

// Populate the email row
function populateEmailRow(recordid, prefix, forwardto) {
    $("#emailforwards").append('<div class="row" id="emailrow-' + recordid + '"><form id="emailform-' + recordid + '"><input type="hidden" name="recordid" id="emailrecordid-' + recordid + '" value="' + recordid + '"><div class="col-lg-4"><input type="text" name="prefix" size="30" value="' + prefix + '"/></div><div class="col-lg-2 text-center"><i class="fa fa-long-arrow-right fa-align-center fa-2x" aria-hidden="true"></i></div><div class="col-lg-4"><input type="text" name="forwardto" size="30" value="' + forwardto + '"/></div><div class="col-lg-2 text-center"><div class="btn-group" role="group" aria-label="..."><button type="button" class="btn btn-danger delRow"><span class="glyphicon glyphicon-trash"></span></button><button type="button" class="btn btn-success saveRow"><span class="glyphicon glyphicon-pencil"></span></button></div></div></form></div>');
}

// --------------------------------------------------
// Any DNS / URL Record related functionality starts here
// --------------------------------------------------
// List DNS / URL records
function listRecords(domainid) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageDNSURLForwarding&op=getRecords";
    var type = "POST";
    var timeout = 1e4;
    var formdata = "";
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url).fail(errorHandler);
    promise.done(function(data) {
        for (i = 0; i < data.length; i++) {
            if (data[i].type == "URL" || data[i].type == "FRAME") {
                populateURLRow(data[i].recordid, data[i].hostname, data[i].type, data[i].address);
            } else {
                populateDNSRow(data[i].recordid, data[i].hostname, data[i].type, data[i].ttl, data[i].address, data[i].priority);
            }
        }
        Toast("success", "toast-top-right", "Successfully retrieved dns / url records");
    });
}

// Add DNS / URL Record
function addRecord(domainid, temprecordid, formdata, recordType) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof temprecordid === "undefined") {
        returnResp.error = "temprecordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Check for optionals
    if (typeof recordType === "undefined") {
        recordType = "dns";
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageDNSURLForwarding&op=addRecord";
    var type = "POST";
    var timeout = 1e4;
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url, formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        // Update data (if dns)
        if (recordType == "dns") {
            $("#row-" + temprecordid).attr("id", "row-" + data.recordID);
            $("#form-" + temprecordid).attr("id", "form-" + data.recordID);
            $("#newrecordid-" + temprecordid).attr("id", "recordid-" + data.recordID);
            $("#recordid-" + data.recordID).val(data.recordID);
            $("#form-" + data.recordID + " input[name=hostname]").val(data.recordName);
            $("#form-" + data.recordID + " input[name=address]").val(data.recordContent);
            $("#form-" + data.recordID + " input[name=ttl]").val(data.recordTTL);
            if (typeof data.recordPrio !== "undefined" && data.recordType == "MX") {
                $("#form-" + data.recordID + " input[name=priority]").val(data.recordPrio);
            } else {
                $("#form-" + data.recordID + " input[name=priority]").val("N/A");
            }
            Toast("success", "toast-top-right", "Successfully added dns record");
        } else if (recordType == "url") {
            $("#urlrow-" + temprecordid).attr("id", "urlrow-" + data.recordID);
            $("#urlform-" + temprecordid).attr("id", "urlform-" + data.recordID);
            $("#urlnewrecordid-" + temprecordid).attr("id", "urlrecordid-" + data.recordID);
            $("#urlrecordid-" + data.recordID).val(data.recordID);
            $("#urlform-" + data.recordID  + " input[name=hostname]").val(data.hostname);
            $("#urlform-" + data.recordID  + " input[name=address]").val(data.url);
            Toast("success", "toast-top-right", "Successfully added url record");
        }
    });
}

// Delete DNS / URL Record
function deleteRecord(domainid, recordid, formdata, recordType) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof recordid === "undefined") {
        returnResp.error = "recordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Check for optionals
    if (typeof recordType === "undefined") {
        recordType = "dns";
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageDNSURLForwarding&op=deleteRecord";
    var type = "POST";
    var timeout = 1e4;
    // Execute the AJAX Call
    var promise = executeAJAXRequest(type, url, formdata, timeout).fail(errorHandler);
    promise.done(function(data) {
        if (recordType == "dns") {
            // Remove this row now
            $("#row-" + recordid).remove();
            Toast("success", "toast-top-right", "Successfully deleted dns record");
        } else if (recordType == "url") {
            // Remove this row now
            $("#urlrow-" + recordid).remove();
            Toast("success", "toast-top-right", "Successfully deleted url record");
        }
    });
}

// Save DNS / URL Record
function saveRecord(domainid, recordid, formdata, recordType) {
    // Declare vars
    var returnResp = {};
    // Check we have what is needed
    if (typeof domainid === "undefined") {
        returnResp.error = "domainid not populated";
        return returnResp;
    }
    if (typeof recordid === "undefined") {
        returnResp.error = "recordid not populated";
        return returnResp;
    }
    if (typeof formdata === "undefined") {
        returnResp.error = "formdata not populated";
        return returnResp;
    }
    // Check for optionals
    if (typeof recordType === "undefined") {
        recordType = "dns";
    }
    // Define our required info
    var url = "clientarea.php?action=domaindetails&id=" + domainid + "&modop=custom&a=manageDNSURLForwarding&op=";
    var type = "POST";
    var timeout = 1e4;
    if (recordType == "dns") {
        // Execute the AJAX Call to delete record
        var promise = executeAJAXRequest(type, url + "deleteRecord", formdata, timeout).fail(errorHandler);
        promise.done(function(data) {
            // Execute the AJAX Call to add record
            var promise = executeAJAXRequest(type, url + "addRecord", formdata, timeout).fail(errorHandler);
            promise.done(function(data) {
                $("#row-" + recordid).attr("id", "row-" + data.recordID);
                $("#form-" + recordid).attr("id", "form-" + data.recordID);
                $("#recordid-" + recordid).attr("id", "recordid-" + data.recordID);
                $("#recordid-" + data.recordID).val(data.recordID);
                $("#form-" + data.recordID + " input[name=hostname]").val(data.recordName);
                $("#form-" + data.recordID + " input[name=address]").val(data.recordContent);
                $("#form-" + data.recordID + " input[name=ttl]").val(data.recordTTL);
                if (typeof data.recordPrio !== "undefined" && data.recordType == "MX") {
                    $("#form-" + data.recordID + " input[name=priority]").val(data.recordPrio);
                } else {
                    $("#form-" + data.recordID + " input[name=priority]").val("N/A");
                }
                Toast("success", "toast-top-right", "Successfully updated dns record");
            });
        });
    } else if (recordType == "url") {
        // Execute the AJAX Call to delete record
        var promise = executeAJAXRequest(type, url + "deleteRecord", formdata, timeout).fail(errorHandler);
        promise.done(function(data) {
            // Execute the AJAX Call to add record
            var promise = executeAJAXRequest(type, url + "addRecord", formdata, timeout).fail(errorHandler);
            promise.done(function(data) {
                $("#urlrow-" + recordid).attr("id", "urlrow-" + data.recordID);
                $("#urlform-" + recordid).attr("id", "urlform-" + data.recordID);
                $("#urlrecordid-" + recordid).attr("id", "urlrecordid-" + data.recordID);
                $("#urlrecordid-" + data.recordID).val(data.recordID);
                $("#urlform-" + data.recordID  + " input[name=hostname]").val(data.hostname);
                $("#urlform-" + data.recordID  + " input[name=address]").val(data.url);
                Toast("success", "toast-top-right", "Successfully updated url record");
            });
        });
    }
}

function populateDNSRow(recordid, hostname, type, ttl, address, priority) {
    // Define dns types
    var dnstypes = {
        A: "A",
        AAAA: "AAAA",
        MX: "MX",
        CNAME: "CNAME",
        TXT: "TXT",
        SRV: "SRV",
        NS: "NS"
    };
    var dnstypeshtml = "";
    var i;
    for (i in dnstypes) {
        if (i == type) {
            dnstypeshtml += '<option value="' + i + '" selected>' + dnstypes[i] + "</option>";
        } else {
            dnstypeshtml += '<option value="' + i + '">' + dnstypes[i] + "</option>";
        }
    }
    if (typeof priority === "undefined") {
        priority = "N/A";
    }
    $("#dnsrecords").append('<div class="row" id="row-' + recordid + '"><form id="form-' + recordid + '"><input type="hidden" name="recordid" id="recordid-' + recordid + '" value="' + recordid + '"><div class="col-lg-3"><input type="text" name="hostname" size="20" value="' + hostname + '"/></div><div class="col-lg-3"><input type="text" name="address" size="20" value="' + address + '"/></div><div class="col-lg-2"><select name="type">' + dnstypeshtml + '</select></div><div class="col-lg-1 plf"><input type="text" name="ttl" size="5" value="' + ttl + '"/></div><div class="col-lg-1"><input type="text" name="priority" size="3" value="' + priority + '"/></div><div class="col-lg-2 text-center"><div class="btn-group" role="group" aria-label="..."><button type="button" class="btn btn-danger delRow"><span class="glyphicon glyphicon-trash"></span></button><button type="button" class="btn btn-success saveRow"><span class="glyphicon glyphicon-pencil"></span></button></div></div></form></div>');
}

function populateURLRow(recordid, hostname, type, address) {
    var urltypes = {
        URL: "URL Forward",
        FRAME: "URL Frame (Cloaking)"
    };
    var urltypeshtml = "";
    var i;
    for (i in urltypes) {
        if (i == type) {
            urltypeshtml += '<option value="' + i + '" selected>' + urltypes[i] + "</option>";
        } else {
            urltypeshtml += '<option value="' + i + '">' + urltypes[i] + "</option>";
        }
    }
    $("#urlforwards").append('<div class="row" id="urlrow-' + recordid + '"><form id="urlform-' + recordid + '"><input type="hidden" name="recordid" id="urlrecordid-' + recordid + '" value="' + recordid + '"><div class="col-lg-3"><input type="text" name="hostname" size="20" value="' + hostname + '"/></div><div class="col-lg-3"><input type="text" name="address" size="20" value="' + address + '"/></div><div class="col-lg-3"><select name="type">' + urltypeshtml + '</select></div><div class="col-lg-2"></div><div class="col-lg-2 text-center"><div class="btn-group" role="group" aria-label="..."><button type="button" class="btn btn-danger delRow"><span class="glyphicon glyphicon-trash"></span></button><button type="button" class="btn btn-success saveRow"><span class="glyphicon glyphicon-pencil"></span></button></div></div></form></div>');
}

// --------------------------------------------------
// Any general functions start here
// --------------------------------------------------
// Confirmation dialgoue
function formConfirm() {
    return confirm("Are you sure you wish to delete?");
}

// Execute the AJAX request
function executeAJAXRequest(type, url, data, timeout) {
    // Default response object
    var respObj = {};
    // Make sure we have everything we need
    if (url == undefined) {
        respObj.error = "url not specified";
        return respObj;
    }
    // Optional vars, if not defined then we define them
    if (timeout == undefined) {
        timeout = 15e3;
    }
    if (type == undefined) {
        type = "GET";
    }
    // Make the AJAX request
    return $.ajax({
        type: type,
        url: url,
        data: data,
        timeout: timeout,
        dataType: "text json"
    }).done(stdSuccessCB);
}

// This callback is used to detect and JSON errors, etc
function stdSuccessCB(result) {
    if (typeof result === "undefined") {
        Toast("error", "toast-top-right", "Unable to parse JSON Response");
    } else {
        if (typeof result.error !== "undefined") {
            Toast("error", "toast-top-right", result.error);
        }
    }
}

function errorHandler(jqXHR, textStatus, errorThrown) {
    console.log(jqXHR);
    console.log(textStatus);
    console.log(errorThrown);
}

// Image preload
function preload(arrayOfImages) {
    $(arrayOfImages).each(function() {
        $("<img/>")[0].src = this;
    });
}

// Show the gears
function showGears() {
    $body = $("body");
    $body.addClass("loading");
}

// Hide the gears
function hideGears() {
    $body = $("body");
    $body.removeClass("loading");
}

function getOldRecordID() {
    // We need to get the old record id
    var myData = $(this)[0].data;
    var pairs = myData.split("&");
    for (var i = 0; len = pairs.length, i < len; i++) {
        var entry = pairs[i];
        var keys = entry.split("=");
        if (keys[0] == "recordid") {
            var oldrecordid = keys[1];
            break;
        }
    }
    return oldrecordid;
}